"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = composeAmplification;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _styledComponents = require("styled-components");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * @public
 * @name composeAmplification
 * @descriptiton This is a HoC that will compose a amplification component
 * @param AbstractAnim {Component} - the react component that will inherit
 * @param variableName {string} - the name of the motion theme variable
 * @return {Component} - the new Amplification component
 */
function composeAmplification(AbstractAnim, variableName) {
  var Amplification = function Amplification(props) {
    var amplification = props.amplification,
        theme = props.theme,
        rest = _objectWithoutProperties(props, ["amplification", "theme"]);

    return _react.default.createElement(AbstractAnim, _extends({
      amplification: amplification || theme.motion[variableName]
    }, rest));
  };
  /* eslint-disable react/require-default-props */


  Amplification.propTypes = {
    theme: _propTypes.default.object,
    amplification: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string])
  };
  /* eslint-enable react/require-default-props */

  return (0, _styledComponents.withTheme)(Amplification);
}

module.exports = exports["default"];