"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = composeRotation;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _styledComponents = require("styled-components");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * @public
 * @name composeRotation
 * @descriptiton This is a HoC that will compose a rotation component
 * @param AbstractAnim {Component} - the react component that will inherit
 * @param variableName {string} - the name of the motion theme variable
 * @return {Component} - the new Rotation component
 */
function composeRotation(AbstractAnim, variableName) {
  var Rotation = function Rotation(props) {
    var rotation = props.rotation,
        theme = props.theme,
        rest = _objectWithoutProperties(props, ["rotation", "theme"]);

    var degree = rotation || theme.motion[variableName];

    if (!isNaN(rotation) || degree.indexOf('deg') === -1) {
      degree = "".concat(parseInt(degree, 10).toString(), "deg");
    }

    return _react.default.createElement(AbstractAnim, _extends({
      rotation: degree
    }, rest));
  };
  /* eslint-disable react/require-default-props */


  Rotation.propTypes = {
    theme: _propTypes.default.object,
    rotation: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number])
  };
  /* eslint-enable react/require-default-props */

  return (0, _styledComponents.withTheme)(Rotation);
}

module.exports = exports["default"];